@@ -6,9 +6,10 @@ log_lin_narpq_init <- function(y, W, p, Z = NULL) {
 
   if ( !is.null(Z) ) {
     Z <- model.matrix( ~., as.data.frame(Z) )
-    Z <- Z[1:dim(y)[1], -1, drop = FALSE]
+    Z <- Z[1:dim(y)[2], -1, drop = FALSE]
   }
 
+  y <- t(y)
   W <- W / Rfast::rowsums(W)
   W[ is.na(W) ] <- 0
 
@@ -22,5 +23,5 @@ log_lin_narpq_init <- function(y, W, p, Z = NULL) {
   XX <- crossprod(wy)
   Xy <- Rfast::eachcol.apply(wy, as.vector( ly[, -c(1:p)] ) )
   x0 <- solve(XX, Xy)
-
+  x0
 }
